# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ItemFinderOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cron_schedule: Optional[List[str]]
    _cron_schedule_description: Optional[str]
    _description: Optional[str]
    _do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]]
    _effective_permissions: Optional[PermissionsV1]
    _enabled: bool
    _executor_id: str
    _id: str
    _include_hierarchy: Optional[bool]
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _last_run_at: Optional[str]
    _last_run_warnings: List[str]
    _name: str
    _scoped_to: Optional[str]
    _searches: List[Any]
    _status_message: Optional[str]
    _timezone: Optional[str]
    _translation_key: Optional[str]
    _type: str


    def __init__(
        self,
        cron_schedule: Optional[List[str]] = None,
        cron_schedule_description: Optional[str] = None,
        description: Optional[str] = None,
        do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        enabled: Optional[bool] = None,
        executor_id: Optional[str] = None,
        id: Optional[str] = None,
        include_hierarchy: Optional[bool] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        last_run_at: Optional[str] = None,
        last_run_warnings: Optional[List[str]] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        searches: Optional[List[Any]] = None,
        status_message: Optional[str] = None,
        timezone: Optional[str] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def cron_schedule(self) -> Optional[List[str]]: ...

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule: Optional[List[str]]) -> None: ...

    @property
    def cron_schedule_description(self) -> Optional[str]: ...

    @cron_schedule_description.setter
    def cron_schedule_description(self, cron_schedule_description: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def do_not_use_hierarchy_search_output(self) -> Optional[List[HierarchySearchOutputV1]]: ...

    @do_not_use_hierarchy_search_output.setter
    def do_not_use_hierarchy_search_output(self, do_not_use_hierarchy_search_output: Optional[List[HierarchySearchOutputV1]]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def enabled(self) -> bool: ...

    @enabled.setter
    def enabled(self, enabled: bool) -> None: ...

    @property
    def executor_id(self) -> str: ...

    @executor_id.setter
    def executor_id(self, executor_id: str) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def include_hierarchy(self) -> Optional[bool]: ...

    @include_hierarchy.setter
    def include_hierarchy(self, include_hierarchy: Optional[bool]) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def last_run_at(self) -> Optional[str]: ...

    @last_run_at.setter
    def last_run_at(self, last_run_at: Optional[str]) -> None: ...

    @property
    def last_run_warnings(self) -> List[str]: ...

    @last_run_warnings.setter
    def last_run_warnings(self, last_run_warnings: List[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def searches(self) -> List[Any]: ...

    @searches.setter
    def searches(self, searches: List[Any]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RunConditionMonitorJobInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'manual_run_data': 'list[ManualRunInputV1]',
        'table_manual_run_data': 'BaseManualRunInputV1'
    }

    attribute_map = {
        'manual_run_data': 'manualRunData',
        'table_manual_run_data': 'tableManualRunData'
    }

    def __init__(self, manual_run_data=None, table_manual_run_data=None):
        """
        RunConditionMonitorJobInputV1 - a model defined in Swagger
        """

        self._manual_run_data = None
        self._table_manual_run_data = None

        if manual_run_data is not None:
          self.manual_run_data = manual_run_data
        if table_manual_run_data is not None:
          self.table_manual_run_data = table_manual_run_data

    @property
    def manual_run_data(self):
        """
        Gets the manual_run_data of this RunConditionMonitorJobInputV1.
        Data for manual run on specific conditions

        :return: The manual_run_data of this RunConditionMonitorJobInputV1.
        :rtype: list[ManualRunInputV1]
        """
        return self._manual_run_data

    @manual_run_data.setter
    def manual_run_data(self, manual_run_data):
        """
        Sets the manual_run_data of this RunConditionMonitorJobInputV1.
        Data for manual run on specific conditions

        :param manual_run_data: The manual_run_data of this RunConditionMonitorJobInputV1.
        :type: list[ManualRunInputV1]
        """

        self._manual_run_data = manual_run_data

    @property
    def table_manual_run_data(self):
        """
        Gets the table_manual_run_data of this RunConditionMonitorJobInputV1.

        :return: The table_manual_run_data of this RunConditionMonitorJobInputV1.
        :rtype: BaseManualRunInputV1
        """
        return self._table_manual_run_data

    @table_manual_run_data.setter
    def table_manual_run_data(self, table_manual_run_data):
        """
        Sets the table_manual_run_data of this RunConditionMonitorJobInputV1.

        :param table_manual_run_data: The table_manual_run_data of this RunConditionMonitorJobInputV1.
        :type: BaseManualRunInputV1
        """

        self._table_manual_run_data = table_manual_run_data

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RunConditionMonitorJobInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelRuleInputV1ListString(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _argument: Optional[List[str]]
    _derived_feature_index: Optional[int]
    _description: Optional[str]
    _id: Optional[str]
    _input_feature_id: Optional[str]
    _input_feature_index: Optional[int]
    _name: str
    _type: str


    def __init__(
        self,
        argument: Optional[List[str]] = None,
        derived_feature_index: Optional[int] = None,
        description: Optional[str] = None,
        id: Optional[str] = None,
        input_feature_id: Optional[str] = None,
        input_feature_index: Optional[int] = None,
        name: Optional[str] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def argument(self) -> Optional[List[str]]: ...

    @argument.setter
    def argument(self, argument: Optional[List[str]]) -> None: ...

    @property
    def derived_feature_index(self) -> Optional[int]: ...

    @derived_feature_index.setter
    def derived_feature_index(self, derived_feature_index: Optional[int]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def input_feature_id(self) -> Optional[str]: ...

    @input_feature_id.setter
    def input_feature_id(self, input_feature_id: Optional[str]) -> None: ...

    @property
    def input_feature_index(self) -> Optional[int]: ...

    @input_feature_index.setter
    def input_feature_index(self, input_feature_index: Optional[int]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CompositeFilter(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _filter1: Optional[Filter]
    _filter2: Optional[Filter]
    _operation: Optional[str]


    def __init__(
        self,
        filter1: Optional[Filter] = None,
        filter2: Optional[Filter] = None,
        operation: Optional[str] = None,
    ) -> None: ...

    @property
    def filter1(self) -> Optional[Filter]: ...

    @filter1.setter
    def filter1(self, filter1: Optional[Filter]) -> None: ...

    @property
    def filter2(self) -> Optional[Filter]: ...

    @filter2.setter
    def filter2(self, filter2: Optional[Filter]) -> None: ...

    @property
    def operation(self) -> Optional[str]: ...

    @operation.setter
    def operation(self, operation: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ValueFilter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_name': 'str',
        'filter_target': 'str',
        'filter_type': 'str',
        'value': 'Value'
    }

    attribute_map = {
        'column_name': 'columnName',
        'filter_target': 'filterTarget',
        'filter_type': 'filterType',
        'value': 'value'
    }

    def __init__(self, column_name=None, filter_target=None, filter_type=None, value=None):
        """
        ValueFilter - a model defined in Swagger
        """

        self._column_name = None
        self._filter_target = None
        self._filter_type = None
        self._value = None

        if column_name is not None:
          self.column_name = column_name
        if filter_target is not None:
          self.filter_target = filter_target
        if filter_type is not None:
          self.filter_type = filter_type
        if value is not None:
          self.value = value

    @property
    def column_name(self):
        """
        Gets the column_name of this ValueFilter.
        The name of the column to filter against. If filtering against context, prepend the name with either 'context_comment.', 'context_label.', or 'context_opaque.'. For example, you can filter for rows with comments updated after a certain date by filtering against 'context_comment.updated_at'

        :return: The column_name of this ValueFilter.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ValueFilter.
        The name of the column to filter against. If filtering against context, prepend the name with either 'context_comment.', 'context_label.', or 'context_opaque.'. For example, you can filter for rows with comments updated after a certain date by filtering against 'context_comment.updated_at'

        :param column_name: The column_name of this ValueFilter.
        :type: str
        """

        self._column_name = column_name

    @property
    def filter_target(self):
        """
        Gets the filter_target of this ValueFilter.
        Specifies where the filter should be applied: ROW (WHERE clause, filters individual rows before grouping) or AGGREGATED (HAVING clause, filters groups after aggregation). Defaults to ROW for backward compatibility.

        :return: The filter_target of this ValueFilter.
        :rtype: str
        """
        return self._filter_target

    @filter_target.setter
    def filter_target(self, filter_target):
        """
        Sets the filter_target of this ValueFilter.
        Specifies where the filter should be applied: ROW (WHERE clause, filters individual rows before grouping) or AGGREGATED (HAVING clause, filters groups after aggregation). Defaults to ROW for backward compatibility.

        :param filter_target: The filter_target of this ValueFilter.
        :type: str
        """

        self._filter_target = filter_target

    @property
    def filter_type(self):
        """
        Gets the filter_type of this ValueFilter.
        The operation to use in combination with the value

        :return: The filter_type of this ValueFilter.
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """
        Sets the filter_type of this ValueFilter.
        The operation to use in combination with the value

        :param filter_type: The filter_type of this ValueFilter.
        :type: str
        """

        self._filter_type = filter_type

    @property
    def value(self):
        """
        Gets the value of this ValueFilter.

        :return: The value of this ValueFilter.
        :rtype: Value
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ValueFilter.

        :param value: The value of this ValueFilter.
        :type: Value
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ValueFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ServerLoadOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'load_percentage': 'float'
    }

    attribute_map = {
        'description': 'description',
        'load_percentage': 'loadPercentage'
    }

    def __init__(self, description=None, load_percentage=None):
        """
        ServerLoadOutputV1 - a model defined in Swagger
        """

        self._description = None
        self._load_percentage = None

        if description is not None:
          self.description = description
        if load_percentage is not None:
          self.load_percentage = load_percentage

    @property
    def description(self):
        """
        Gets the description of this ServerLoadOutputV1.
        A human readable description of what is most causing the server load.

        :return: The description of this ServerLoadOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ServerLoadOutputV1.
        A human readable description of what is most causing the server load.

        :param description: The description of this ServerLoadOutputV1.
        :type: str
        """

        self._description = description

    @property
    def load_percentage(self):
        """
        Gets the load_percentage of this ServerLoadOutputV1.
        A rough percentage of load that the server is experiencing, where 0.0 is entirely unloaded and 1.0 is entirely busy. Note, a load of greater than 1.0 is possible and perhaps normal, but it indicates the server is queuing effort and some users may have a degraded experience.

        :return: The load_percentage of this ServerLoadOutputV1.
        :rtype: float
        """
        return self._load_percentage

    @load_percentage.setter
    def load_percentage(self, load_percentage):
        """
        Sets the load_percentage of this ServerLoadOutputV1.
        A rough percentage of load that the server is experiencing, where 0.0 is entirely unloaded and 1.0 is entirely busy. Note, a load of greater than 1.0 is possible and perhaps normal, but it indicates the server is queuing effort and some users may have a degraded experience.

        :param load_percentage: The load_percentage of this ServerLoadOutputV1.
        :type: float
        """

        self._load_percentage = load_percentage

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerLoadOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableComputeOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compute_results': 'dict(str, list[RowRulesResultV1])',
        'table_definition': 'TableDefinitionOutputV1'
    }

    attribute_map = {
        'compute_results': 'computeResults',
        'table_definition': 'tableDefinition'
    }

    def __init__(self, compute_results=None, table_definition=None):
        """
        TableComputeOutputV1 - a model defined in Swagger
        """

        self._compute_results = None
        self._table_definition = None

        if compute_results is not None:
          self.compute_results = compute_results
        if table_definition is not None:
          self.table_definition = table_definition

    @property
    def compute_results(self):
        """
        Gets the compute_results of this TableComputeOutputV1.
        The compute results for this table definition

        :return: The compute_results of this TableComputeOutputV1.
        :rtype: dict(str, list[RowRulesResultV1])
        """
        return self._compute_results

    @compute_results.setter
    def compute_results(self, compute_results):
        """
        Sets the compute_results of this TableComputeOutputV1.
        The compute results for this table definition

        :param compute_results: The compute_results of this TableComputeOutputV1.
        :type: dict(str, list[RowRulesResultV1])
        """
        if compute_results is None:
            raise ValueError("Invalid value for `compute_results`, must not be `None`")

        self._compute_results = compute_results

    @property
    def table_definition(self):
        """
        Gets the table_definition of this TableComputeOutputV1.

        :return: The table_definition of this TableComputeOutputV1.
        :rtype: TableDefinitionOutputV1
        """
        return self._table_definition

    @table_definition.setter
    def table_definition(self, table_definition):
        """
        Sets the table_definition of this TableComputeOutputV1.

        :param table_definition: The table_definition of this TableComputeOutputV1.
        :type: TableDefinitionOutputV1
        """
        if table_definition is None:
            raise ValueError("Invalid value for `table_definition`, must not be `None`")

        self._table_definition = table_definition

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableComputeOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardFilterOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _board_id: str
    _config: Optional[str]
    _display_type: Optional[str]
    _id: str


    def __init__(
        self,
        board_id: Optional[str] = None,
        config: Optional[str] = None,
        display_type: Optional[str] = None,
        id: Optional[str] = None,
    ) -> None: ...

    @property
    def board_id(self) -> str: ...

    @board_id.setter
    def board_id(self, board_id: str) -> None: ...

    @property
    def config(self) -> Optional[str]: ...

    @config.setter
    def config(self, config: Optional[str]) -> None: ...

    @property
    def display_type(self) -> Optional[str]: ...

    @display_type.setter
    def display_type(self, display_type: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class MaterializedTablesApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def delete_rows(
        self,
        **kwargs: Any,
    ) -> DeleteRowsOutputV1: ...

    def delete_rows_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def publish_events(
        self,
        **kwargs: Any,
    ) -> PublishEventsOutputV1: ...

    def publish_events_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def recompute_table(
        self,
        **kwargs: Any,
    ) -> RecomputeTableOutputV1: ...

    def recompute_table_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelFormulaCreatorRuleV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _description: Optional[ModelRuleInputV1String]
    _formula: ModelRuleInputV1String
    _identity_id: Optional[ModelRuleInputV1UUID]
    _name: ModelRuleInputV1String
    _parameters: ModelRuleInputV1ListString
    _permission_string: Optional[ModelRuleInputV1String]
    _scoped_to: Optional[ModelRuleInputV1UUID]
    _variable_parameter_strings: Optional[ModelRuleInputV1ListString]
    _variable_parameters: Optional[ModelRuleInputV1ListString]


    def __init__(
        self,
        description: Optional[ModelRuleInputV1String] = None,
        formula: Optional[ModelRuleInputV1String] = None,
        identity_id: Optional[ModelRuleInputV1UUID] = None,
        name: Optional[ModelRuleInputV1String] = None,
        parameters: Optional[ModelRuleInputV1ListString] = None,
        permission_string: Optional[ModelRuleInputV1String] = None,
        scoped_to: Optional[ModelRuleInputV1UUID] = None,
        variable_parameter_strings: Optional[ModelRuleInputV1ListString] = None,
        variable_parameters: Optional[ModelRuleInputV1ListString] = None,
    ) -> None: ...

    @property
    def description(self) -> Optional[ModelRuleInputV1String]: ...

    @description.setter
    def description(self, description: Optional[ModelRuleInputV1String]) -> None: ...

    @property
    def formula(self) -> ModelRuleInputV1String: ...

    @formula.setter
    def formula(self, formula: ModelRuleInputV1String) -> None: ...

    @property
    def identity_id(self) -> Optional[ModelRuleInputV1UUID]: ...

    @identity_id.setter
    def identity_id(self, identity_id: Optional[ModelRuleInputV1UUID]) -> None: ...

    @property
    def name(self) -> ModelRuleInputV1String: ...

    @name.setter
    def name(self, name: ModelRuleInputV1String) -> None: ...

    @property
    def parameters(self) -> ModelRuleInputV1ListString: ...

    @parameters.setter
    def parameters(self, parameters: ModelRuleInputV1ListString) -> None: ...

    @property
    def permission_string(self) -> Optional[ModelRuleInputV1String]: ...

    @permission_string.setter
    def permission_string(self, permission_string: Optional[ModelRuleInputV1String]) -> None: ...

    @property
    def scoped_to(self) -> Optional[ModelRuleInputV1UUID]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[ModelRuleInputV1UUID]) -> None: ...

    @property
    def variable_parameter_strings(self) -> Optional[ModelRuleInputV1ListString]: ...

    @variable_parameter_strings.setter
    def variable_parameter_strings(self, variable_parameter_strings: Optional[ModelRuleInputV1ListString]) -> None: ...

    @property
    def variable_parameters(self) -> Optional[ModelRuleInputV1ListString]: ...

    @variable_parameters.setter
    def variable_parameters(self, variable_parameters: Optional[ModelRuleInputV1ListString]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableSearchInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_ids': 'list[str]',
        'fixed_item_ids': 'list[str]',
        'row_ids': 'list[str]',
        'source_table_id': 'str'
    }

    attribute_map = {
        'column_ids': 'columnIds',
        'fixed_item_ids': 'fixedItemIds',
        'row_ids': 'rowIds',
        'source_table_id': 'sourceTableId'
    }

    def __init__(self, column_ids=None, fixed_item_ids=None, row_ids=None, source_table_id=None):
        """
        TableSearchInputV1 - a model defined in Swagger
        """

        self._column_ids = None
        self._fixed_item_ids = None
        self._row_ids = None
        self._source_table_id = None

        if column_ids is not None:
          self.column_ids = column_ids
        if fixed_item_ids is not None:
          self.fixed_item_ids = fixed_item_ids
        if row_ids is not None:
          self.row_ids = row_ids
        if source_table_id is not None:
          self.source_table_id = source_table_id

    @property
    def column_ids(self):
        """
        Gets the column_ids of this TableSearchInputV1.
        Column IDs to search in the source table. Each column will be searched for items to include as rows in the result.

        :return: The column_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._column_ids

    @column_ids.setter
    def column_ids(self, column_ids):
        """
        Sets the column_ids of this TableSearchInputV1.
        Column IDs to search in the source table. Each column will be searched for items to include as rows in the result.

        :param column_ids: The column_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._column_ids = column_ids

    @property
    def fixed_item_ids(self):
        """
        Gets the fixed_item_ids of this TableSearchInputV1.
        Fixed item IDs to include in the backing table. These items will be included regardless of the source table search.

        :return: The fixed_item_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._fixed_item_ids

    @fixed_item_ids.setter
    def fixed_item_ids(self, fixed_item_ids):
        """
        Sets the fixed_item_ids of this TableSearchInputV1.
        Fixed item IDs to include in the backing table. These items will be included regardless of the source table search.

        :param fixed_item_ids: The fixed_item_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._fixed_item_ids = fixed_item_ids

    @property
    def row_ids(self):
        """
        Gets the row_ids of this TableSearchInputV1.
        Row IDs to filter results. If provided, only items in these rows will be included from the column results.

        :return: The row_ids of this TableSearchInputV1.
        :rtype: list[str]
        """
        return self._row_ids

    @row_ids.setter
    def row_ids(self, row_ids):
        """
        Sets the row_ids of this TableSearchInputV1.
        Row IDs to filter results. If provided, only items in these rows will be included from the column results.

        :param row_ids: The row_ids of this TableSearchInputV1.
        :type: list[str]
        """

        self._row_ids = row_ids

    @property
    def source_table_id(self):
        """
        Gets the source_table_id of this TableSearchInputV1.
        Source table ID containing the columns to search. Required if columnIds is provided.

        :return: The source_table_id of this TableSearchInputV1.
        :rtype: str
        """
        return self._source_table_id

    @source_table_id.setter
    def source_table_id(self, source_table_id):
        """
        Sets the source_table_id of this TableSearchInputV1.
        Source table ID containing the columns to search. Required if columnIds is provided.

        :param source_table_id: The source_table_id of this TableSearchInputV1.
        :type: str
        """

        self._source_table_id = source_table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableSearchInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.1-v202604020723-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TileLayoutOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _height: int
    _id: str
    _width: int
    _x: int
    _y: int


    def __init__(
        self,
        height: Optional[int] = None,
        id: Optional[str] = None,
        width: Optional[int] = None,
        x: Optional[int] = None,
        y: Optional[int] = None,
    ) -> None: ...

    @property
    def height(self) -> int: ...

    @height.setter
    def height(self, height: int) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def width(self) -> int: ...

    @width.setter
    def width(self, width: int) -> None: ...

    @property
    def x(self) -> int: ...

    @x.setter
    def x(self, x: int) -> None: ...

    @property
    def y(self) -> int: ...

    @y.setter
    def y(self, y: int) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
